@@ -1,13 +1,11 @@
 import datetime
 import discord
-from cheesyutils.discord_bots import DiscordBot
 from contextlib import redirect_stdout
 from discord.ext import commands
 from io import StringIO
 from textwrap import indent
 from traceback import format_exc
 
-
 class CogConverter(commands.Converter):
     async def convert(self, ctx: commands.Context, argument: str) -> commands.Cog:
         cog = ctx.bot.get_cog(argument)
@@ -21,7 +19,7 @@ class Meta(commands.Cog):
     Default commands and listeners and stuffs
     """
 
-    def __init__(self, bot: DiscordBot):
+    def __init__(self, bot):
         self.bot = bot
     
     @staticmethod
@@ -139,7 +137,7 @@ class Meta(commands.Cog):
 
     @commands.is_owner()
     @commands.bot_has_permissions(send_messages=True)
-    @_cog_group.command()
+    @_cog_group.command(name="list")
     async def _cog_list_command(self, ctx: commands.Context):
         """
         Lists all cogs currently running on the bot
