@@ -29,7 +29,7 @@ def get_discord_color(color: Union[discord.Color, tuple, str]) -> discord.Color:
     elif type(color) is str:
         # code snippet taken from https://stackoverflow.com/a/29643643
         return get_discord_color(tuple(int(color.lstrip("#")[i:i + 2], 16) for i in (0, 2, 4)))
-    elif type(color) is discord.Color:
+    elif isinstance(color, (discord.Color, discord.Colour)):
         return color
     else:
         raise TypeError("Invalid Color type. Must be discord.Color, RGB tuple, or hex string")
